# style.tcl --
#
# This demonstration script creates a text widget that illustrates the
# various display styles that may be set for tags.
#
# SCCS: @(#) style.tcl 1.5 96/02/16 10:49:24

set w .style
catch {destroy $w}
toplevel $w
wm title $w "Text Demonstration - Display Styles"
wm iconname $w "style"
positionWindow $w

frame $w.buttons
pack $w.buttons -side bottom -fill x -pady 2m
button $w.buttons.dismiss -text λ -command "destroy $w"
button $w.buttons.code -text "ɻ" -command "showCode $w"
pack $w.buttons.dismiss $w.buttons.code -side left -expand 1

text $w.text -yscrollcommand "$w.scroll set" -setgrid true \
	-width 70 -height 32 -wrap word
scrollbar $w.scroll -command "$w.text yview"
pack $w.scroll -side right -fill y
pack $w.text -expand yes -fill both

# Set up display styles

$w.text tag configure bold -font -*-Courier-Bold-O-Normal--*-120-*-*-*-*-*-*
$w.text tag configure big -font -*-Courier-Bold-R-Normal--*-140-*-*-*-*-*-*
$w.text tag configure verybig -font \
	-*-Helvetica-Bold-R-Normal--*-240-*-*-*-*-*-*
if {[winfo depth $w] > 1} {
    $w.text tag configure color1 -background #a0b7ce
    $w.text tag configure color2 -foreground red
    $w.text tag configure raised -relief raised -borderwidth 1
    $w.text tag configure sunken -relief sunken -borderwidth 1
} else {
    $w.text tag configure color1 -background black -foreground white
    $w.text tag configure color2 -background black -foreground white
    $w.text tag configure raised -background white -relief raised \
	    -borderwidth 1
    $w.text tag configure sunken -background white -relief sunken \
	    -borderwidth 1
}
$w.text tag configure bgstipple -background black -borderwidth 0 \
	-bgstipple gray12
$w.text tag configure fgstipple -fgstipple gray50
$w.text tag configure underline -underline on
$w.text tag configure overstrike -overstrike on
$w.text tag configure right -justify right
$w.text tag configure center -justify center
$w.text tag configure super -offset 4p \
	-font -Adobe-Courier-Medium-R-Normal--*-100-*-*-*-*-*-*
$w.text tag configure sub -offset -2p \
	-font -Adobe-Courier-Medium-R-Normal--*-100-*-*-*-*-*-*
$w.text tag configure margins -lmargin1 12m -lmargin2 6m -rmargin 10m
$w.text tag configure spacing -spacing1 10p -spacing2 2p \
	-lmargin1 12m -lmargin2 6m -rmargin 10m

$w.text insert end {Τ褦˥ƥ widget Ͼ͡ʥɽ뤳
Ǥޤ}
$w.text insert end  big
$w.text insert end {Ȥᥫ˥ǥȥ뤵ޤ
Ȥϥƥ widget Τʸ (ϰ)ФŬѤǤ
ñʤ̾ΤȤǤ͡ɽǤޤ
ꤹȡΥΤĤʸϻꤷɽ
褦ˤʤޤѤǤɽϼ̤Ǥ
}
$w.text insert end {
1. ե} big
$w.text insert end {    ɤ X ΥեȤǤȤޤ}
$w.text insert end large verybig
$w.text insert end {
Ȥ}
$w.text insert end small small
$w.text insert end {Ȥ
}
$w.text insert end {
2. } big
$w.text insert end {  }
$w.text insert end {طʿ} color1
$w.text insert end {}
$w.text insert end {ʿ} color2
$w.text insert end {}
$w.text insert end {ξ} {color1 color2}
$w.text insert end {ȤѤ뤳ȤǤޤ
}
$w.text insert end {
3. ֤} big
$w.text insert end {  Τ褦κݤ}
$w.text insert end {طʤ} bgstipple
$w.text insert end {ʸ} fgstipple
$w.text insert end {ñʤɤĤ֤
Ǥʤ֤ȤȤǤޤ
}
$w.text insert end {
4. } big
$w.text insert end {  Τ褦}
$w.text insert end {ʸ˲} underline
$w.text insert end {ȤǤޤ
}
$w.text insert end {
5. Ǥä} big
$w.text insert end {  Τ褦}
$w.text insert end {ʸ˽Ťͤ} overstrike
$w.text insert end {ȤǤޤ
}
$w.text insert end {
6. 3D } big
$w.text insert end {  طʤȤĤơʸ}
$w.text insert end {ӽФ} raised
$w.text insert end {褦ˤ}
$w.text insert end {} sunken
$w.text insert end {
褦ˤǤޤ
}
$w.text insert end {
7. ·} big
$w.text insert end { Τ褦˹Ԥ
}
$w.text insert end {·
}
$w.text insert end {·, 
} right
$w.text insert end {·Ǥޤ
} center
$w.text insert end {
8. դʸź}  big
$w.text insert end {  10}
$w.text insert end {n} super
$w.text insert end { Τ褦˸դʸθ̤䡢}
$w.text insert end {
X}
$w.text insert end {i} sub
$w.text insert end {Τ褦źθ̤ФȤǤޤ
}
$w.text insert end {
9. ޡ} big
$w.text insert end {ƥȤκ¦;ʬʶ}
$w.text insert end {֤ȤǤޤ:
}
$w.text insert end {ϥޡλǤ꡼} margins
$w.text insert end {ޤ֤ɽƤ1ԤΥƥȤǤ} margins
$w.text insert end {¦ˤ2Υޡޤ} margins
$w.text insert end {1ܤФΤȡ} margins
$w.text insert end {2ܰʹߤϢ³ޡ} margins
$w.text insert end {Ǥޤ¦ˤޡ󤬤ޤ} margins
$w.text insert end {Ԥޤ֤֤뤿˻Ѥ뤳ȤǤޤ
} margins
$w.text insert end {
10. ڡ} big
$w.text insert end {3ĤΥѥ᡼ǹԤΥڡ󥰤}
$w.text insert end {椹
뤳ȤǤޤSpacing1ǡԤ}
$w.text insert end {ˤɤΤ餤ζ֤֤
spacing3}
$w.text insert end {ǹԤβˤɤΤ餤ζ֤֤}
$w.text insert end {Ԥޤ֤Ƥʤ
Сspacing2ǡ}
$w.text insert end {ƥȹԤƤԤδ֤ˤɤΤ餤}
$w.text insert end {ζ֤
򼨤ޤ
}
$w.text insert end {ΥǥȤ줿ϤɤΤ褦} spacing
$w.text insert end {ڡ󥰤ԤΤ򼨤ޤ} spacing
$w.text insert end {ϼºݤϥƥwidget} spacing
$w.text insert end {1ԤǡwidgetˤäޤޤƤޤ
} spacing
$w.text insert end {Spacing1ϤΥƥȤǤ10point} spacing
$w.text insert end {ꤵƤޤ} spacing
$w.text insert end {ˤꡢδ֤礭ʴֳ֤} spacing
$w.text insert end {¸ߤƤޤ} spacing
$w.text insert end {Spacing22pointꤵƤޤ} spacing
$w.text insert end {ˤۤξֳ֤¸ߤƤޤ} spacing
$w.text insert end {Spacing3ϤǤϻѤƤޤ
} spacing
$w.text insert end {ֳ֤ɤˤ뤫򸫤С} spacing
$w.text insert end {ʤǥƥȤ򤷤Ƥ} spacing
$w.text insert end {ȿžʬˤ;ʬˤȤ줿ֳ֤} spacing
$w.text insert end {ޤޤƤޤ
} spacing
